# irdata

A data processing library for [iRefIndex](https://github.com/abotzki/irefindex).
The source code is originally by @iandonaldson. It copied/extracted from [here](https://github.com/iandonaldson/irefindex/tree/master/irdata).
